@@ -20,7 +20,7 @@
 
 #include <QRegExp>
 #include <KLocalizedString>
-#include <qfiledialog.h>
+#include <QFileDialog>
 #include <QTemporaryFile>
 
 using namespace MailImporter;
